ngff_zarr.methods._itk - ngff-zarr
Description: Module Contents: Functions:,,_compute_itk_gaussian_kernel_radius, Get kernel radius in xyzt directions,,_itk_blur_and_downsample, Blur and then downsample a given image chunk,,_downsample_itk_bin_s...

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# `ngff_zarr.methods._itk`

## Module Contents

### Functions

`_compute_itk_gaussian_kernel_radius` | Get kernel radius in xyzt directions
`_itk_blur_and_downsample` | Blur and then downsample a given image chunk
`_downsample_itk_bin_shrink` |
`_downsample_itk_gaussian` |

### Data

`_image_dims` |

### API

ngff_zarr.methods._itk._image_dims: Tuple[str, str, str, str]

  (‘x’, ‘y’, ‘z’, ‘t’)

ngff_zarr.methods._itk._compute_itk_gaussian_kernel_radius(input_size, sigma_values) → list

  Get kernel radius in xyzt directions

ngff_zarr.methods._itk._itk_blur_and_downsample(image_data, gaussian_filter_name, interpolator_name, shrink_factors, sigma_values, kernel_radius)

  Blur and then downsample a given image chunk

ngff_zarr.methods._itk._downsample_itk_bin_shrink(ngff_image: ngff_zarr.ngff_image.NgffImage, default_chunks, out_chunks, scale_factors)

ngff_zarr.methods._itk._downsample_itk_gaussian(ngff_image: ngff_zarr.ngff_image.NgffImage, default_chunks, out_chunks, scale_factors)